==> cli-0.61.18.tgz: package/src/utils.ts <==
import { collect } from '@stacksjs/collections'

export * as kolorist from 'kolorist'

export {
  stripAnsi,
  centerAlign,
  rightAlign,
  leftAlign,
  align,
  box,
  colors,
  getColor,
  colorize,
} from 'consola/utils'

export {
  ansi256Bg,
  bgBlack,
  bgBlue,
  bgCyan,
  bgGray,
  bgGreen,
  bgLightBlue,
  bgLightCyan,
  bgLightGray,
  bgLightGreen,
  bgLightMagenta,
  bgLightRed,
  bgLightYellow,
  bgMagenta,
  bgRed,
  bgWhite,
  bgYellow,
  black,
  blue,
  bold,
  cyan,
  dim,
  gray,
  green,
  hidden,
  inverse,
  italic,
  lightBlue,
  lightCyan,
  lightGray,
  lightGreen,
  lightMagenta,
  lightRed,
  lightYellow,
  link,
  magenta,
  red,
  reset,
  strikethrough,
  underline,
  white,
  yellow,
  ansi256,
  trueColor,
  trueColorBg,
  stripColors,
} from 'kolorist'

export const quotes = collect([
  // could be queried from any API or database
  'The best way to get started is to quit talking and begin doing.',
  'The pessimist sees difficulty in every opportunity. The optimist sees opportunity in every difficulty.',
  'Don’t let yesterday take up too much of today.',
  'You learn more from failure than from success. Don’t let it stop you. Failure builds character.',
  'It’s not whether you get knocked down, it’s whether you get up.',
  'If you are working on something that you really care about, you don’t have to be pushed. The vision pulls you.',
  'People who are crazy enough to think they can change the world, are the ones who do.',
  'Failure will never overtake me if my determination to succeed is strong enough.',
  'Entrepreneurs are great at dealing with uncertainty and also very good at minimizing risk. That’s the classic entrepreneur.',
  'We may encounter many defeats but we must not be defeated.',
  'Knowing is not enough; we must apply. Wishing is not enough; we must do.',
  'Imagine your life is perfect in every respect; what would it look like?',
  'We generate fears while we sit. We overcome them by action.',
  'Whether you think you can or think you can’t, you’re right.',
  'Security is mostly a superstition. Life is either a daring adventure or nothing.',
])

==> cli-0.65.0.tgz: package/src/utils.ts <==
import { collect, type Collection } from '@stacksjs/collections'

export {
  align,
  box,
  centerAlign,
  colorize,
  colors,
  getColor,
  leftAlign,
  rightAlign,
  stripAnsi,
} from 'consola/utils'

export * as kolorist from 'kolorist'

export {
  ansi256,
  ansi256Bg,
  bgBlack,
  bgBlue,
  bgCyan,
  bgGray,
  bgGreen,
  bgLightBlue,
  bgLightCyan,
  bgLightGray,
  bgLightGreen,
  bgLightMagenta,
  bgLightRed,
  bgLightYellow,
  bgMagenta,
  bgRed,
  bgWhite,
  bgYellow,
  black,
  blue,
  bold,
  cyan,
  dim,
  gray,
  green,
  hidden,
  inverse,
  italic,
  lightBlue,
  lightCyan,
  lightGray,
  lightGreen,
  lightMagenta,
  lightRed,
  lightYellow,
  link,
  magenta,
  red,
  reset,
  strikethrough,
  stripColors,
  trueColor,
  trueColorBg,
  underline,
  white,
  yellow,
} from 'kolorist'

export const quotes: Collection<string> = collect([
  // could be queried from any API or database
  'The best way to get started is to quit talking and begin doing.',
  'The pessimist sees difficulty in every opportunity. The optimist sees opportunity in every difficulty.',
  'Don’t let yesterday take up too much of today.',
  'You learn more from failure than from success. Don’t let it stop you. Failure builds character.',
  'It’s not whether you get knocked down, it’s whether you get up.',
  'If you are working on something that you really care about, you don’t have to be pushed. The vision pulls you.',
  'People who are crazy enough to think they can change the world, are the ones who do.',
  'Failure will never overtake me if my determination to succeed is strong enough.',
  'Entrepreneurs are great at dealing with uncertainty and also very good at minimizing risk. That’s the classic entrepreneur.',
  'We may encounter many defeats but we must not be defeated.',
  'Knowing is not enough; we must apply. Wishing is not enough; we must do.',
  'Imagine your life is perfect in every respect; what would it look like?',
  'We generate fears while we sit. We overcome them by action.',
  'Whether you think you can or think you can’t, you’re right.',
  'Security is mostly a superstition. Life is either a daring adventure or nothing.',
])
